@@ -70,40 +70,40 @@ boa.init <- function(recover = FALSE)
                   title        = TRUE), envir = globalenv())
       assign(".boa.pardesc",
             structure(rbind(
-               c("Analysis", "Brooks, Gelman & Rubin", "Alpha Level", "alpha",
+               c("Convergence", "Brooks, Gelman, & Rubin", "Alpha Level", "alpha",
                   ""),
-               c("Analysis", "Brooks, Gelman & Rubin", "Window Fraction",
+               c("Convergence", "Brooks, Gelman, & Rubin", "Window Fraction",
                   "gandr.win", ""),
-               c("Analysis", "Geweke", "Window 1 Fraction", "geweke.first", ""),
-               c("Analysis", "Geweke", "Window 2 Fraction", "geweke.last", ""),
-               c("Analysis", "Heidelberger & Welch", "Accuracy", "handw.error",
+               c("Convergence", "Geweke", "Window 1 Fraction", "geweke.first", ""),
+               c("Convergence", "Geweke", "Window 2 Fraction", "geweke.last", ""),
+               c("Convergence", "Heidelberger & Welch", "Accuracy", "handw.error",
                   ""),
-               c("Analysis", "Heidelberger & Welch", "Alpha Level", "alpha",
+               c("Convergence", "Heidelberger & Welch", "Alpha Level", "alpha",
                   ""),
-               c("Analysis", "Raftery & Lewis", "Accuracy", "randl.error", ""),
-               c("Analysis", "Raftery & Lewis", "Alpha Level", "alpha", ""),
-               c("Analysis", "Raftery & Lewis", "Delta", "randl.delta", ""),
-               c("Analysis", "Raftery & Lewis", "Quantile", "randl.q", ""),
-               c("Analysis", "Statistics", "ACF Lags", "acf.lags", ""),
-               c("Analysis", "Statistics", "Alpha Level", "alpha", ""),
-               c("Analysis", "Statistics", "Batch Size", "batch.size", ""),
-               c("Analysis", "Statistics", "Quantiles", "quantiles", ""),
-               c("Data", "Files", "Working Directory", "path",
-                  "Specified directory must not end with a slash"),
-               c("Data", "Files", "ASCII File Ext", "ASCIIext", ""),
-               c("Plot", "Brooks & Gelman", "Number of Bins", "gandr.bins", ""),
-               c("Plot", "Brooks & Gelman", "Window Fraction", "gandr.win", ""),
-               c("Plot", "Density", "Bandwidth", "bandwidth",
+               c("Convergence", "Raftery & Lewis", "Accuracy", "randl.error", ""),
+               c("Convergence", "Raftery & Lewis", "Alpha Level", "alpha", ""),
+               c("Convergence", "Raftery & Lewis", "Delta", "randl.delta", ""),
+               c("Convergence", "Raftery & Lewis", "Quantile", "randl.q", ""),
+               c("Convergence Plot", "Brooks & Gelman", "Number of Bins", "gandr.bins", ""),
+               c("Convergence Plot", "Brooks & Gelman", "Window Fraction", "gandr.win", ""),
+               c("Convergence Plot", "Gelman & Rubin", "Alpha Level", "alpha", ""),
+               c("Convergence Plot", "Gelman & Rubin", "Number of Bins", "gandr.bins", ""),
+               c("Convergence Plot", "Gelman & Rubin", "Window Fraction", "gandr.win", ""),
+               c("Convergence Plot", "Geweke", "Alpha Level", "alpha", ""),
+               c("Convergence Plot", "Geweke", "Number of Bins", "geweke.bins", ""),
+               c("Convergence Plot", "Geweke", "Window 1 Fraction", "geweke.first", ""),
+               c("Convergence Plot", "Geweke", "Window 2 Fraction", "geweke.last", ""),
+               c("Descriptive", "Statistics", "ACF Lags", "acf.lags", ""),
+               c("Descriptive", "Statistics", "Alpha Level", "alpha", ""),
+               c("Descriptive", "Statistics", "Batch Size", "batch.size", ""),
+               c("Descriptive", "Statistics", "Quantiles", "quantiles", ""),
+               c("Descriptive Plot", "Density", "Bandwidth", "bandwidth",
                   "This defines the standard deviation of the smoothing kernel"),
-               c("Plot", "Density", "Kernel", "kernel",
+               c("Descriptive Plot", "Density", "Kernel", "kernel",
                   "Possible kernels are gaussian, rectangular, triangular, or cosine"),
-               c("Plot", "Gelman & Rubin", "Alpha Level", "alpha", ""),
-               c("Plot", "Gelman & Rubin", "Number of Bins", "gandr.bins", ""),
-               c("Plot", "Gelman & Rubin", "Window Fraction", "gandr.win", ""),
-               c("Plot", "Geweke", "Alpha Level", "alpha", ""),
-               c("Plot", "Geweke", "Number of Bins", "geweke.bins", ""),
-               c("Plot", "Geweke", "Window 1 Fraction", "geweke.first", ""),
-               c("Plot", "Geweke", "Window 2 Fraction", "geweke.last", ""),
+               c("Import", "Files", "Working Directory", "path",
+                  "Use forward slashes (\'/\') as directory separators and omit a terminating slash"),
+               c("Import", "Files", "ASCII File Ext", "ASCIIext", ""),
                c("Plot", "Graphics", "Legend", "legend",
                   "Include plot legends (T/F)"),
                c("Plot", "Graphics", "Title", "title", "Include plot title (T/F)"),
@@ -125,7 +125,7 @@ boa.init <- function(recover = FALSE)
             list(name     = "BOA",
                   major    = 1,
                   minor    = 1,
-                  revision = 5,
+                  revision = 6,
                   system   = version$system), envir = globalenv())
       boa.license()
    }
