@@ -8,8 +8,8 @@ function(lname, pname, annotate = boa.par("legend"))
    if(is.matrix(parm)) {
       drawn <- TRUE
       result <- acf(parm, plot = FALSE)
-      plot(result$lag, result$acf, xlab = "Lag", ylab = pname,
-           ylim = c(-1, 1), type = "h")
+      plot(result$lag, result$acf, xlab = "Lag", ylab = "Autocorrelation",
+           main = pname, ylim = c(-1, 1), type = "h")
       abline(0, 0)
       usr <- par("usr")
       if (annotate)
